@@ -10,6 +10,7 @@ fields in each record may be populated. See
 https://dev.maxmind.com/geoip/docs/web-services?lang=en for more details.
 
 """
+
 # pylint: disable=too-many-instance-attributes,too-few-public-methods
 import ipaddress
 from abc import ABCMeta
@@ -470,7 +471,7 @@ class ASN(SimpleModel):
     autonomous_system_number: Optional[int]
     autonomous_system_organization: Optional[str]
 
-    # pylint:disable=too-many-arguments
+    # pylint:disable=too-many-arguments,too-many-positional-arguments
     def __init__(self, raw: Dict[str, Union[str, int]]) -> None:
         super().__init__(raw)
         self.autonomous_system_number = cast(
@@ -494,6 +495,7 @@ class ConnectionType(SimpleModel):
       - Cable/DSL
       - Corporate
       - Cellular
+      - Satellite
 
       Additional values may be added in the future.
 
@@ -621,7 +623,7 @@ class ISP(ASN):
     mobile_network_code: Optional[str]
     organization: Optional[str]
 
-    # pylint:disable=too-many-arguments
+    # pylint:disable=too-many-arguments,too-many-positional-arguments
     def __init__(self, raw: Dict[str, Union[str, int]]) -> None:
         super().__init__(raw)
         self.isp = cast(Optional[str], raw.get("isp"))
